@@ -21,8 +21,12 @@ class Products(Client):
         1                                       1
         ======================================  ==============
 
-        Args:
+        Examples:
+            literal blocks::
 
+                Products().get_product_pricing_for_skus(['sku', 'sku1'], MarketplaceId="ATVPDKIKX0DER")
+
+        Args:
             seller_sku_list: [str]
             item_condition: str ("New", "Used", "Collectible", "Refurbished", "Club")
             **kwargs:
@@ -49,13 +53,17 @@ class Products(Client):
         1                                       1
         ======================================  ==============
 
+        Examples:
+            literal blocks::
 
-        :param asin_list: [str]
-        :param item_condition: str ("New", "Used", "Collectible", "Refurbished", "Club")
-           Filters the offer listings based on item condition. Possible values: New, Used, Collectible, Refurbished, Club.
-           Available values : New, Used, Collectible, Refurbished, Club
-        :param kwargs:
-        :return: ApiResponse
+                Products().get_product_pricing_for_asins(['asin1', 'asin2'], MarketplaceId="ATVPDKIKX0DER")
+
+        Args:
+            asin_list: [str]
+            item_condition: str | ("New", "Used", "Collectible", "Refurbished", "Club") Filters the offer listings based on item condition. Possible values: New, Used, Collectible, Refurbished, Club. Available values : New, Used, Collectible, Refurbished, Club
+
+        Returns:
+            ApiResponse
         """
         if item_condition is not None:
             kwargs['ItemCondition'] = item_condition
@@ -76,10 +84,16 @@ class Products(Client):
         1                                       1
         ======================================  ==============
 
+        Examples:
+            literal blocks::
 
-        :param seller_sku_list: [str]
-        :param kwargs:
-        :return: ApiResponse
+                Products().get_competitive_pricing_for_skus([], MarketplaceId="ATVPDKIKX0DER")
+
+        Args:
+            seller_sku_list: [str]
+
+        Returns:
+            ApiResponse
         """
         return self._create_get_pricing_request(seller_sku_list, 'Sku', **kwargs)
 
@@ -97,10 +111,16 @@ class Products(Client):
         1                                       1
         ======================================  ==============
 
+        Examples:
+            literal blocks::
 
-        :param asin_list: [str]
-        :param kwargs:
-        :return:
+                Products().get_competitive_pricing_for_asins([], MarketplaceId="ATVPDKIKX0DER")
+
+        Args:
+            asin_list: [str]
+
+        Returns:
+            ApiResponse
 
         """
         return self._create_get_pricing_request(asin_list, 'Asin', **kwargs)
@@ -120,12 +140,12 @@ class Products(Client):
         ======================================  ==============
 
         Args:
-            :param seller_sku: str
+            seller_sku: str
             key ItemCondition: str | Possible values: New, Used, Collectible, Refurbished, Club.
             key MarketplaceId: str
 
         Returns:
-            GetOffersResponse:
+            ApiResponse
 
         """
         return self._request(fill_query_params(kwargs.pop('path'), seller_sku), params={**kwargs})       
@@ -145,12 +165,12 @@ class Products(Client):
         ======================================  ==============
 
         Args:
-            :param seller_sku: str
+            seller_sku: str
             key ItemCondition: str | Possible values: New, Used, Collectible, Refurbished, Club.
             key MarketplaceId: str
 
         Returns:
-            GetOffersResponse:
+            ApiResponse
 
         """
         return self._request(fill_query_params(kwargs.pop('path'), asin), params={**kwargs})
