@@ -2,6 +2,7 @@ import urllib.parse
 import zlib
 from collections import abc
 from datetime import datetime
+from io import BytesIO, StringIO
 
 import requests
 
@@ -105,6 +106,10 @@ class Reports(Client):
         Returns:
             ApiResponse
         """
+        if isinstance(kwargs.get('dataStartTime', None), datetime):
+            kwargs.update({'dataStartTime': kwargs.get('dataStartTime').isoformat()})
+        if isinstance(kwargs.get('dataEndTime', None), datetime):
+            kwargs.update({'dataEndTime': kwargs.get('dataEndTime').isoformat()})
         return self._request(kwargs.pop('path'), data=kwargs)
 
     @sp_endpoint('/reports/2021-06-30/reports/{}', method='DELETE')
@@ -371,7 +376,10 @@ class Reports(Client):
                 if isinstance(file, str):
                     with open(file, "w+", encoding=character_code) as text_file:
                         text_file.write(document)
-                else:
+                if isinstance(file, BytesIO):
+                    file.write(document.encode(character_code))
+                    file.seek(0)
+                elif isinstance(file, StringIO):
                     file.write(document)
                     file.seek(0)
         return res
